#
# spec file for package jansi
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           jansi
Version:        2.4.0
Release:        3.2
Summary:        Java library for generating and interpreting ANSI escape sequences
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://fusesource.github.io/jansi/
Source0:        %{name}-%{version}.tar.xz
Source1:        %{name}-build.xml
Patch0:         %{name}-jni.patch
BuildRequires:  ant
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  javapackages-local >= 6

%description
Jansi is a java library that allows you to use ANSI escape sequences
in your Java console applications. It implements ANSI support on platforms
which don't support it, like Windows, and provides graceful degradation for
when output is being sent to output devices which cannot support ANSI sequences.

%package javadoc
Summary:        Javadocs for %{name}
Group:          Documentation/HTML
BuildArch:      noarch

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q
cp %{SOURCE1} build.xml

%pom_remove_parent

# We don't need the Fuse JXR skin
%pom_xpath_remove "pom:build/pom:extensions"

# Plugins not needed for an RPM build
%pom_remove_plugin :maven-gpg-plugin
%pom_remove_plugin :maven-javadoc-plugin
%pom_remove_plugin :nexus-staging-maven-plugin

# We don't want GraalVM support in Fedora
%pom_remove_plugin :exec-maven-plugin
%pom_remove_dep :picocli-codegen

# Build for JDK 1.8 at a minimum
%pom_xpath_set "//pom:properties/pom:jdkTarget" 1.8

# Link the JNI headers
ln -s %{_jvmdir}/java/include/jni.h src/main/native/inc_linux
ln -s %{_jvmdir}/java/include/linux/jni_md.h src/main/native/inc_linux

# Set the JNI path
sed -i 's,@LIBDIR@,%{_libdir},' \
    src/main/java/org/fusesource/jansi/internal/JansiLoader.java
# Filtering complicated with ant
sed -i 's,\${project.version},%{version},' \
    src/main/resources/org/fusesource/jansi/jansi.properties

%build
# Build the native artifact
CFLAGS="$CFLAGS -I. -fPIC -fvisibility=hidden"
pushd src/main/native
gcc $CFLAGS -c jansi.c
gcc $CFLAGS -c jansi_isatty.c
gcc $CFLAGS -c jansi_structs.c
gcc $CFLAGS -c jansi_ttyname.c
gcc $CFLAGS $LDFLAGS -shared -o libjansi.so *.o -lutil
popd

# Build the Java artifacts
%{ant} jar javadoc

%install
# Install the native artifact
install -dm 0755 %{buildroot}%{_libdir}/%{name}
install -pm 0755 src/main/native/libjansi.so %{buildroot}%{_libdir}/%{name}

# jar
install -dm 0755 %{buildroot}%{_jnidir}/%{name}
install -pm 0644 target/%{name}-%{version}.jar %{buildroot}%{_jnidir}/%{name}/%{name}.jar
# pom
install -dm 0755 %{buildroot}%{_mavenpomdir}/%{name}
%{mvn_install_pom} pom.xml %{buildroot}%{_mavenpomdir}/%{name}/%{name}.pom
%add_maven_depmap %{name}/%{name}.pom %{name}/%{name}.jar
# javadoc
%fdupes -s %{buildroot}%{_javadocdir}
# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license license.txt
%doc readme.md changelog.md
%{_libdir}/%{name}

%files javadoc
%{_javadocdir}/%{name}

%changelog
* Sun Sep 29 2024 Fridrich Strba <fstrba@suse.com>
- Fix build after removal of the default %%%%{java_home} define
* Wed Apr 26 2023 Fridrich Strba <fstrba@suse.com>
- Fetch sources using source_service and don't distribute legally
  spurious files (bsc#1210877)
* Mon May 16 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade the latest upstream release 2.4.0
  * Integrates jansi-native libraries
  * Does not depend on jansi-native and hawtjni-runtime
- Make the jansi package archful since it installs a native
  library and jni jar
- Added patch:
  * jansi-jni.patch
    + Give a possibility to load the native libjansi.so from
    system
* Wed Mar 23 2022 Fridrich Strba <fstrba@suse.com>
- Build with java source and target levels 8
* Thu Jun 27 2019 Fridrich Strba <fstrba@suse.com>
- Remove the reference to jansi-project parent from jansi pom
- Resolve manually jansi-native-version variable so that ivy
  understands it
* Tue Apr  9 2019 Fridrich Strba <fstrba@suse.com>
- Remove reference to the parent pom since we are not building
  using Maven.
- Make tests conditional and switched off by default
* Thu Feb  7 2019 Jan Engelhardt <jengelh@inai.de>
- Fix double-shipping of documentation
- Avoid name repetition in summary (potential rpmlint warning
* Mon Feb  4 2019 Fridrich Strba <fstrba@suse.com>
- Initial package of jansi 1.17.1
- Add build.xml file for building with ant
